from .files import secure_files_bp
from .settings import secure_settings_bp
from .users import (secure_logout_bp,
                    secure_login_bp,
                    change_passwords_bp,
                    secure_users_bp
                    )

from .views import secure_views_bp
from .chats import secure_chat_bp
